<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>CDayMonthView</name>
    <message>
        <source>Monday</source>
        <translation>Maandag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dinsdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Woensdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Donderdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Vrijdag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Zaterdag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Zondag</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <source>Y</source>
        <translation>J</translation>
    </message>
    <message>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <source>New Event</source>
        <translation>Nieuwe afspraak</translation>
    </message>
</context>
<context>
    <name>CMonthGraphiview</name>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Je verwijdert een afspraak.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Weet je zeker dat je deze afspraak wilt verwijderen?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Wil je alle afspraken in de reeks verwijderen of enkel deze?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Reeks verwijderen</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Deze afspraak verwijderen</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Wil je deze en toekomstige afspraken verwijderen of enkel deze?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Toekomstige afspraken verwijderen</translation>
    </message>
</context>
<context>
    <name>CMonthSchceduleNumButton</name>
    <message>
        <source>%1 more</source>
        <translation>Nog %1 andere</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <source>New event</source>
        <translation>Nieuwe afspraak</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation>Nieuwe afspraak</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <source>Y</source>
        <translation>J</translation>
    </message>
</context>
<context>
    <name>CMySchceduleView</name>
    <message>
        <source>You are deleting an event.</source>
        <translation>Je verwijdert een afspraak.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Weet je zeker dat je deze afspraak wilt verwijderen?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Wil je alle afspraken in de reeks verwijderen of enkel deze?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Reeks verwijderen</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Deze afspraak verwijderen</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Wil je deze en toekomstige afspraken verwijderen of enkel deze?</translation>
    </message>
    <message>
        <source>My Event</source>
        <translation>Mijn afspraak</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Aanpassen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Oké</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Toekomstige afspraken verwijderen</translation>
    </message>
</context>
<context>
    <name>CSchceduleDlg</name>
    <message>
        <source>New Event</source>
        <translation>Nieuwe afspraak</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation>Afspraak aanpassen</translation>
    </message>
    <message>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation>Alle afspraken in reeks moeten voorzien zijn van de status &apos;hele dag&apos;.</translation>
    </message>
    <message>
        <source>Do you want to change all occurrences?</source>
        <translation>Wil je alle afspraken in de reeks aanpassen?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Change All</source>
        <translation>Reeks aanpassen</translation>
    </message>
    <message>
        <source>You are changing the repeating rule of this event.</source>
        <translation>Je past de herhaalinstellingen van deze afspraak aan.</translation>
    </message>
    <message>
        <source>You are changing a repeating event.</source>
        <translation>Je past een reeks afspraken aan.</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation>Wil je deze en toekomstige afspraken aanpassen of enkel deze?</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Reeks</translation>
    </message>
    <message>
        <source>Only This Event</source>
        <translation>Deze afspraak</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation>Wil je deze en toekomstige afspraken aanpassen of enkel deze?</translation>
    </message>
    <message>
        <source>All Future Events</source>
        <translation>Toekomstige afspraken</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nooit</translation>
    </message>
    <message>
        <source>At time of event</source>
        <translation>Bij aanvang</translation>
    </message>
    <message>
        <source>15 minutes before</source>
        <translation>15 minuten van tevoren</translation>
    </message>
    <message>
        <source>30 minutes before</source>
        <translation>30 minuten van tevoren</translation>
    </message>
    <message>
        <source>1 hour before</source>
        <translation>1 uur van tevoren</translation>
    </message>
    <message>
        <source>1 day before</source>
        <translation>1 dag van tevoren</translation>
    </message>
    <message>
        <source>2 days before</source>
        <translation>2 dagen van tevoren</translation>
    </message>
    <message>
        <source>1 week before</source>
        <translation>1 week van tevoren</translation>
    </message>
    <message>
        <source>On start day (9:00 AM)</source>
        <translation>Op de dag van de afspraak (9:00 AM)</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Soort:</translation>
    </message>
    <message>
        <source>All Day:</source>
        <translation>Hele dag:</translation>
    </message>
    <message>
        <source>Remind Me:</source>
        <translation>Herinneren:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Herhalen:</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>Dagelijks</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Werkdagen</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation>Wekelijks</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation>Maandelijks</translation>
    </message>
    <message>
        <source>Yearly</source>
        <translation>Jaarlijks</translation>
    </message>
    <message>
        <source>End Repeat:</source>
        <translation>Herhaling eindigt op:</translation>
    </message>
    <message>
        <source>After</source>
        <translation>Na</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Op</translation>
    </message>
    <message>
        <source>time(s)</source>
        <translation>keer</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>New event</source>
        <translation>Nieuwe afspraak</translation>
    </message>
    <message>
        <source>End time must be greater than start time</source>
        <translation>De eindtijd moet later zijn dan de begintijd</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Oké</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Soort</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation>Hele dag</translation>
    </message>
    <message>
        <source>Starts</source>
        <translation>Begint om</translation>
    </message>
    <message>
        <source>Ends</source>
        <translation>Eindigt om</translation>
    </message>
    <message>
        <source>Remind Me</source>
        <translation>Herinneren</translation>
    </message>
    <message>
        <source>Repeat</source>
        <translation>Herhalen</translation>
    </message>
    <message>
        <source>End Repeat</source>
        <translation>Herhaling stoppen</translation>
    </message>
    <message>
        <source>Ends:</source>
        <translation>Einde:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Omschrijving:</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Omschrijving</translation>
    </message>
    <message>
        <source>Starts:</source>
        <translation>Begin:</translation>
    </message>
    <message>
        <source>Work</source>
        <translation>Werk</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Privé</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Overig</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchDateItem</name>
    <message>
        <source>Y</source>
        <translation>J</translation>
    </message>
    <message>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchItem</name>
    <message>
        <source>Edit</source>
        <translation>Aanpassen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Je verwijdert een afspraak.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Weet je zeker dat je deze afspraak wilt verwijderen?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Wil je alle afspraken in de reeks verwijderen of enkel deze?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Reeks verwijderen</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Deze afspraak verwijderen</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Wil je deze en toekomstige afspraken verwijderen of enkel de deze?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Toekomstige afspraken verwijderen</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation>Hele dag</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchView</name>
    <message>
        <source>No search results</source>
        <translation>Geen zoekresultaten</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <source>ALL DAY</source>
        <translation>HELE DAG</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <source>Week</source>
        <translation>Week</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>J</translation>
    </message>
</context>
<context>
    <name>CYearSchceduleItem</name>
    <message>
        <source>All Day</source>
        <translation>Hele dag</translation>
    </message>
</context>
<context>
    <name>CYearSchceduleView</name>
    <message>
        <source>All Day</source>
        <translation>Hele dag</translation>
    </message>
    <message>
        <source>No event</source>
        <translation>Geen afspraak</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <source>Y</source>
        <translation>J</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <source>Calendar</source>
        <translation>Kalender</translation>
    </message>
    <message>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation>Met Kalender kun je je afspraken en planning beheren, zowel werk als privé.</translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <source>Calendar</source>
        <translation>Kalender</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>J</translation>
    </message>
    <message>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <source>All Day</source>
        <translation>Hele dag</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <source>Edit</source>
        <translation>Aanpassen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>New event</source>
        <translation>Nieuwe afspraak</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Je verwijdert een afspraak.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Weet je zeker dat je deze afspraak wilt verwijderen?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Wil je alle afspraken in de reeks verwijderen of enkel deze?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Reeks verwijderen</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Deze afspraak verwijderen</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Wil je deze en toekomstige afspraken verwijderen of enkel deze?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Toekomstige afspraken verwijderen</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation>Nieuwe afspraak</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation>Vandaag</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation>Vandaag</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <source>Delete event</source>
        <translation>Afspraak verwijderen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Knippen</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Plakken</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Alles selecteren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <source>Y</source>
        <translation>J</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation>Vandaag</translation>
    </message>
</context>
</TS>